{% include "header.html" %}

<h1>{{ template.title }} - Collections</h1>

<table>
  <thead>
    <tr>
      <th>#</th>
      <th>Title</th>
      <th>Type</th>
      <th>Description</th>
    </tr>
  </thead>
  <tbody>
{% for collection in response.collections %}
    <tr>
      <td>{{ loop.index1 }}</td>
      <td><a href="{{ template.api_root }}/collections/{{ collection.id }}?f=html">{{ collection.title }}</a></td>
      <td>{{ collection.itemType }}</td>
      <td>{{ collection.description }}</td>
    </tr>
{% endfor %}
  </tbody>
</table>

{% include "footer.html" %}
