{% if existsIn(template.tags, "debug") %}
  {% if template.tags.debug == "true" %}
<h2>Template Data</h2>
<p>
  API Root: {{ template.api_root }}<br>    
  Path: {{ template.path }}<br>
  Params: {{ template.params }}<br>
  Title: {{ template.title }}<br>
  Tags: {{ template.tags }}<br>
</p>
  {% endif %}
{% endif %}
